@@ -88,6 +88,7 @@ def heatmap_crosstab_from_df(
     xlabel : Optional[str] = None,
     ylabel : Optional[str] = None,
     save_fig_path : Optional[str] = None,
+    skip_all : bool = False, 
     vis_var : Optional[vs.VisVariables] = None,
 ) -> None:
     """Create crosstab heatmap from dataframe. 
@@ -101,13 +102,15 @@ def heatmap_crosstab_from_df(
         xlabel : xlabel.
         ylabel : ylabel.
         save_fig_path : to save file path.
+        skip_all : If True, and normalize takes "index", "columns" or All, 
+            margins=True is passed to 
         vis_var : Although title, xlabel, and ylabel are contained in vis_var,
             vis_var is given priority to the above parameters.
 
     Note:
         If vis_var is None, the following code is run.
         
-        >>> vis_var = vs.VisVariables( rotation=90,  figsize=(4,3),  cmap_name="haline", annotate=True)
+        >>> vis_var = vs.VisVariables( xrotation=90,  figsize=(4,3),  cmap_name="haline", annotate=True)
         >>> if normalize is not None:
         >>>     vis_var.title = f"{qdc_row.var_name},{qdc_col.var_name},per"
         >>>     vis_var.annotate_fmt = ".1f"
@@ -123,16 +126,17 @@ def heatmap_crosstab_from_df(
     ser_row = dfM[qdc_row.var_name]
     ser_col = dfM[qdc_col.var_name]
     if normalize is not None:
-        tab= (pd.crosstab(ser_row, ser_col, normalize=normalize, margins=True)
+        margins = False if skip_all else True
+        tab= (pd.crosstab(ser_row, ser_col, normalize=normalize, margins=margins)
                    .mul(100)
                    .round(2)
                   )
     else:
-        tab     = pd.crosstab(ser_row, ser_col, normalize=False, margins=True)
+        tab     = pd.crosstab(ser_row, ser_col, normalize=False, margins=False)
     tab = utils.imputate_reorder_table(tab, rows_=order_row, cols_=order_col)
 
     if vis_var is None:
-        vis_var = vs.VisVariables( rotation=90,  figsize=(4,3),  cmap_name="haline", annotate=True)
+        vis_var = vs.VisVariables( xrotation=90,  figsize=(4,3),  cmap_name="haline", annotate=True)
         if normalize is not None:
             vis_var.title = f"{qdc_row.var_name},{qdc_col.var_name},per"
             vis_var.annotate_fmt = ".1f"
